@@ -182,8 +182,16 @@ gsm_util_get_saved_session_dir (void)
         return _saved_session_dir;
 }
 
-char **
-gsm_util_get_autostart_dirs ()
+static char ** autostart_dirs;
+
+void
+gsm_util_set_autostart_dirs (char ** dirs)
+{
+        autostart_dirs = g_strdupv (dirs);
+}
+
+static char **
+gsm_util_get_standard_autostart_dirs ()
 {
         GPtrArray          *dirs;
         const char * const *system_config_dirs;
@@ -215,6 +223,16 @@ gsm_util_get_autostart_dirs ()
         return (char **) g_ptr_array_free (dirs, FALSE);
 }
 
+char **
+gsm_util_get_autostart_dirs ()
+{
+        if (autostart_dirs) {
+                return g_strdupv ((char **)autostart_dirs);
+        }
+
+        return gsm_util_get_standard_autostart_dirs ();
+}
+
 char **
 gsm_util_get_app_dirs ()
 {
@@ -248,6 +266,7 @@ gsm_util_get_desktop_dirs (gboolean include_saved_session,
 {
 	char **apps;
 	char **autostart;
+	char **standard_autostart;
 	char **result;
 	int    size;
 	int    i;
@@ -255,9 +274,18 @@ gsm_util_get_desktop_dirs (gboolean include_saved_session,
 	apps = gsm_util_get_app_dirs ();
 	autostart = gsm_util_get_autostart_dirs ();
 
+        /* Still, check the standard autostart dirs for things like fulfilling session reqs,
+         * if using a non-standard autostart dir for autostarting */
+        if (autostart_dirs != NULL)
+                standard_autostart = gsm_util_get_standard_autostart_dirs ();
+        else
+                standard_autostart = NULL;
+
 	size = 0;
 	for (i = 0; apps[i] != NULL; i++) { size++; }
 	for (i = 0; autostart[i] != NULL; i++) { size++; }
+        if (autostart_dirs != NULL)
+                for (i = 0; standard_autostart[i] != NULL; i++) { size++; }
         if (include_saved_session)
                 size += 1;
 
@@ -272,6 +300,11 @@ gsm_util_get_desktop_dirs (gboolean include_saved_session,
                 for (i = 0; autostart[i] != NULL; i++, size++) {
                         result[size] = autostart[i];
                 }
+                if (standard_autostart != NULL) {
+                        for (i = 0; standard_autostart[i] != NULL; i++, size++) {
+                                result[size] = standard_autostart[i];
+                        }
+                }
                 for (i = 0; apps[i] != NULL; i++, size++) {
                         result[size] = apps[i];
                 }
@@ -279,6 +312,11 @@ gsm_util_get_desktop_dirs (gboolean include_saved_session,
                 for (i = 0; apps[i] != NULL; i++, size++) {
                         result[size] = apps[i];
                 }
+                if (standard_autostart != NULL) {
+                        for (i = 0; standard_autostart[i] != NULL; i++, size++) {
+                                result[size] = standard_autostart[i];
+                        }
+                }
                 for (i = 0; autostart[i] != NULL; i++, size++) {
                         result[size] = autostart[i];
                 }
@@ -289,6 +327,7 @@ gsm_util_get_desktop_dirs (gboolean include_saved_session,
 
 	g_free (apps);
 	g_free (autostart);
+	g_free (standard_autostart);
 
 	result[size] = NULL;
 
